@@ -14,6 +14,8 @@
 #' @param method Parameter "method" in \code{\link{protectTable}} or \code{\link{protectLinkedTables}}.
 #'        Default is "SIMPLEHEURISTIC". Other allowed values are
 #'        "OPT", "HITAS" and "HYPERCUBE". The latter is not possible in cases with two linked tables.
+#'        Alternatively this parameter can be a named list specifying parameters for running tau-argus (see details).
+#'        Experimental wrapper methods according to \code{\link{PTwrap}} is also possible (see details).
 #' @param findLinked When TRUE, the function may find two linked tables and run protectLinkedTables.
 #' @param total String used to name totals.
 #' @param addName When TRUE the variable name is added to the level names, except for variables with most levels.
@@ -55,7 +57,8 @@
 #' @param infoAsFrame When TRUE output element info is a data frame (useful in Shiny).
 #' @param IncProgress A function to report progress (incProgress in Shiny).
 #' @param ...  Further parameters sent to \code{\link{protectTable}} (possibly via \code{\link{protectLinkedTables}})
-#'        such as verbose (print output while calculating) and timeLimit.
+#'        such as verbose (print output while calculating) and timeLimit. 
+#'        Parameters to \code{\link{createArgusInput}} and \code{\link{PTwrap}} is also possible (see details).
 #' 
 #' @details One or two tables are identified automatically and subjected to cell suppression 
 #'          by \code{\link{protectTable}} (single table) or \code{\link{protectLinkedTables}} (two linked tables).
@@ -66,7 +69,27 @@
 #'          This is taken directly from the output from sdcTable. In cases with two linked tables "u" or "x" 
 #'          for common cells are based on output from the first table.
 #'          
-#'          NOTE: The use of numVarInd, weightInd and sampWeightInd in sdcTable is not implemented.
+#'          \strong{To run tau-argus} specify "method" as a named list containing the
+#'          parameter "exe" for \code{\link{runArgusBatchFile}} and other parameters for 
+#'          \code{\link{createArgusInput}}.  
+#'          
+#'          One may specify:  
+#'          \code{method = list(exe="C:/Tau/TauArgus.exe", typ="tabular", path= getwd(),} 
+#'          \code{solver= "FREE", method= "OPT")}
+#'           
+#'          However these values of "exe", "path" and "solver" and "method" are set by default so in this case 
+#'          using "\code{method = list(typ="tabular", method= "OPT")}" is equivalent.
+#'          
+#'          If \code{typ="microdata"} is specified. Necessary transformation to microdata will be made. 
+#'          
+#'          \strong{Wrapper methods (experimental):}
+#'          In the function \code{\link{PTwrap}} several additional methods are defined. 
+#'          If input to ProtectTable() is one of these methods ProtectTable() will 
+#'          be run via PTwrap(). So making explicit call to PTwrap() is not needed.
+#'               
+#'          
+#'          NOTE: The use of numVarInd, weightInd and sampWeightInd in sdcTable is not implemented. This also limit possible 
+#'          input to  tau-argus.
 #'
 #' @return When singleOutput=TRUE output is a list of two elements.
 #' 
@@ -83,7 +106,7 @@
 #' @importFrom SSBtools AutoSplit Stack SortRows Unstack
 #' @importFrom utils capture.output flush.console
 #' 
-#' @seealso protectTable makes a call to the function \code{\link{ProtectTable1}}.
+#' @seealso ProtectTable makes a call to the function \code{\link{ProtectTable1}}.
 #'
 #'
 #' @examples
@@ -123,6 +146,23 @@
 #'                split="_")  # Three variables when splitting
 #'  ProtectTable(z3wb,1:3,4:15,varName=c("hovedint","mnd","mnd2"), 
 #'                split="_",namesAsInput=FALSE,orderAsInput=FALSE) # Alternative ouput format
+#'                
+#'  # ====  Examples Tau-Argus ====              
+#'  exe  <- "C:/Users/oyl/R/TauArgus/TauWindows4.1.4_updated/TauArgus4.1.4/TauArgus.exe"
+#'  path <- "C:/Users/oyl/Documents/work/tull"
+#'  z1 = EasyData("z1") 
+#'  ProtectTable(z1,1:2,3,method=list(exe=exe, path=path, typ="tabular", method="OPT")) 
+#'  ProtectTable(z1,1:2,3,method=list(exe=exe, path=path, typ="tabular", method="MOD")) 
+#'  ProtectTable(z1,1:2,3,method=list(exe=exe, path=path, typ="tabular", method="GH"))
+#'  z1$ant[17] = 0 
+#'   ProtectTable(z1,1:2,3,maxN=-1,
+#'    method=list(path=path, exe=exe, method="OPT",primSuppRules= list(
+#'    list(type="freq", n=4, rg=20),
+#'    list(type="zero", rg=1)
+#'    )))
+#'  z3w <- EasyData("z3")
+#'  ProtectTable(z3,c(1:2,4,5),7,maxN=-1,
+#'    method=list(path=path, exe=exe, method="OPT",primSuppRules=list(list(type="freq", n=4, rg=20))))
 #'                }
 ProtectTable  <-  function(data,
                          dimVar=1:NCOL(data),
@@ -160,6 +200,15 @@ ProtectTable  <-  function(data,
                          IncProgress = IncDefault,
                          ...) {
   IncProgress()
+  tauArgus <- is.list(method)
+  if(!tauArgus) 
+    if(method %in% c("Simple","SimpleSingle","TauArgus","TauArgusOPT","TauArgusMOD","TauArgusGH")){
+      sysCall <- sys.call()
+      sysCall[[1]] <- as.name("PTwrap")
+      parentFrame = parent.frame()
+      return(eval(sysCall, envir=parentFrame))
+  }
+  
   if (is.character(dimVar)) 
     dimVarInd <- match(dimVar, names(data)) else dimVarInd <- dimVar
     if (is.character(freqVar)) 
@@ -205,12 +254,18 @@ ProtectTable  <-  function(data,
                  c("protectZeros",protectZeros),
                  c("maxN",maxN)
           ),stringsAsFactors=FALSE)
-          names(i00) <- c("method",method)   #c("Parameter","Choice")
+          if(!tauArgus) names(i00) <- c("method",method)   #c("Parameter","Choice")
+          else names(i00) <- c("method","TauArgus")
           if (stacked) 
           i0 <- data.frame(InputName=rownames(rowData),as.data.frame(as.matrix(rowData),stringsAsFactors=FALSE),stringsAsFactors=FALSE) else i0 <- NULL
           i1 <- as.data.frame(as.matrix(pt$common$info),stringsAsFactors=FALSE)
-          i2 <- as.data.frame(capture.output(sdcTable::summary(pt$table1[[1]])),stringsAsFactors=FALSE)
-          names(i2) = "Summary1sdcTable"            
+          if(!tauArgus){
+            i2 <- as.data.frame(capture.output(sdcTable::summary(pt$table1[[1]])),stringsAsFactors=FALSE)
+            names(i2) = "Summary1sdcTable"            
+          } else {
+            i2 <- as.data.frame(capture.output(print(method)),stringsAsFactors=FALSE)
+            names(i2) = "TauArgus"            
+          }   # i2 = NULL  
           if (!is.null(pt$table2[[1]])) {
             i3 <- as.data.frame(capture.output(sdcTable::summary(pt$table2[[1]])),stringsAsFactors=FALSE)
             names(i3) = "Summary2sdcTable"
@@ -222,7 +277,11 @@ ProtectTable  <-  function(data,
           i0 <- capture.output(print(rowData)) else i0 <- NULL
       
         i1 <- capture.output(print(pt$common$info))
-        i2 <- capture.output(sdcTable::summary(pt$table1[[1]])) ## Wrong in html Vignette without "sdcTable::"
+        if(!tauArgus){ 
+          i2 <- capture.output(sdcTable::summary(pt$table1[[1]])) ## Wrong in html Vignette without "sdcTable::"
+        } else 
+          i2 <- capture.output(print(method)) ## Wrong in html Vignette without "sdcTable::"
+          #i2 = NULL  
         if (!is.null(pt$table2[[1]])) 
           i3 <- capture.output(sdcTable::summary(pt$table2[[1]])) else i3 <- NULL
       
@@ -245,7 +304,20 @@ ProtectTable  <-  function(data,
       
       
       if (is.null(pt[[2]][[1]])) {
-        finalData <- as.data.frame(getInfo(pt[[1]][[1]], type = "finalData"))
+        if(!tauArgus){ 
+          finalData <- as.data.frame(getInfo(pt[[1]][[1]], type = "finalData"))
+        } else{
+          finalData <- as.data.frame(pt[[1]][[1]])  ## Start treating tauArgus
+          names(finalData)[names(finalData)=="freq"] <- "Freq"
+          if(!is.null(finalData$cellvalue)){
+            if(is.null(finalData$Freq)) finalData$Freq  <- finalData$cellvalue
+            finalData$cellvalue <- NULL
+          }
+          if(!is.null(finalData$sdcStatus_argus)){
+            finalData$sdcStatus  <- finalData$sdcStatus_argus
+            finalData$sdcStatus_argus <- NULL
+          }
+        }                                          ## End treating tauArgus
       } else {
         t1 <- as.data.frame(getInfo(pt[[1]][[1]], type = "finalData"))
         t2 <- as.data.frame(getInfo(pt[[2]][[1]], type = "finalData"))
@@ -291,12 +363,20 @@ ProtectTable  <-  function(data,
       rownames(finalData) <- NULL
       
       suppressed <- finalData$Freq
-      suppressed[!finalData$sdcStatus == "s"] <- suppression
+      
+      if(protectZeros)
+        suppressed[!finalData$sdcStatus == "s"] <- suppression
+      else
+        suppressed[!(finalData$sdcStatus == "s" | finalData$sdcStatus == "z") ] <- suppression
+      
       
       finalData$supp6547524 <- suppressed
       
       IncProgress()
       cat("\n")
+      
+      attributes(finalData)$index <- NULL  # avoid attribute
+      
       if (stacked & doUnstack) {
         if (is.null(singleOutput)) 
           singleOutput <- FALSE
@@ -350,7 +430,6 @@ ProtectTable  <-  function(data,
         }
         
         if (orderAsInput) {
-          # Fungerer ikke (Fungerer nå?) å ha denne før unstack
           
           namesOrig <- dimVarNamesOrig[dimVarNamesOrig %in% names(gVC)]
           
